@@ -18,12 +18,14 @@
 //
 // [1] https://github.com/emk/heroku-buildpack-rust
 
+// TODO: use built-in webhook support
+
 use teloxide::{
     dispatching::{
         stop_token::AsyncStopToken,
         update_listeners::{self, StatefulListener},
     },
-    prelude2::*,
+    prelude::*,
     types::Update,
 };
 
@@ -41,7 +43,7 @@ async fn main() {
 
     let bot = Bot::from_env().auto_send();
 
-    teloxide::repls2::repl_with_listener(
+    teloxide::repl_with_listener(
         bot.clone(),
         |msg: Message, bot: AutoSend<Bot>| async move {
             bot.send_message(msg.chat.id, "pong").await?;
@@ -66,8 +68,8 @@ pub async fn webhook(bot: AutoSend<Bot>) -> impl update_listeners::UpdateListene
         .expect("PORT value to be integer");
     // Heroku host example .: "heroku-ping-pong-bot.herokuapp.com"
     let host = env::var("HOST").expect("have HOST env variable");
-    let path = format!("bot{}", teloxide_token);
-    let url = Url::parse(&format!("https://{}/{}", host, path)).unwrap();
+    let path = format!("bot{teloxide_token}");
+    let url = Url::parse(&format!("https://{host}/{path}")).unwrap();
 
     bot.set_webhook(url).await.expect("Cannot setup a webhook");
 
@@ -85,7 +87,7 @@ pub async fn webhook(bot: AutoSend<Bot>) -> impl update_listeners::UpdateListene
 
     let (stop_token, stop_flag) = AsyncStopToken::new_pair();
 
-    let addr = format!("0.0.0.0:{}", port).parse::<SocketAddr>().unwrap();
+    let addr = format!("0.0.0.0:{port}").parse::<SocketAddr>().unwrap();
     let server = warp::serve(server);
     let (_addr, fut) = server.bind_with_graceful_shutdown(addr, stop_flag);
 
