@@ -1,18 +1,20 @@
 //! Receiving updates from Telegram.
 //!
 //! The key trait here is [`UpdateListener`]. You can get its implementation
-//! using one these functions:
+//! from:
 //!
-//! - [`polling_default`], which returns a default long polling listener.
-//! - [`polling`], which returns a long polling listener with your
+//! - [`polling_default`] function, which returns a default long polling
+//!   listener.
+//! - [`polling`] function, which returns a long polling listener with your
 //!   configuration.
+//! - Various functions in the [`webhooks`] module that return webhook listeners
 //!
 //! And then you can extract updates from it or pass them directly to a
 //! [`Dispatcher`].
 //!
 //! Telegram supports two ways of [getting updates]: [long polling] and
-//! [webhooks]. Currently, only the former one is implemented (see [`polling()`]
-//! and [`polling_default`]). See also [README FAQ about webhooks](https://github.com/teloxide/teloxide/blob/master/README.md#faq).
+//! [webhooks]. For the former see [`polling`] and [`polling_default`], for the
+//! latter see the [`webhooks`] module.
 //!
 //! [`UpdateListener`]: UpdateListener
 //! [`polling_default`]: polling_default
@@ -23,6 +25,11 @@
 //! [long polling]: https://en.wikipedia.org/wiki/Push_technology#Long_polling
 //! [webhooks]: https://en.wikipedia.org/wiki/Webhook
 
+/// Implementations of webhook update listeners - an alternative (to
+/// [`fn@polling`]) way of receiving updates from telegram.
+#[cfg(any(feature = "webhooks-axum"))]
+pub mod webhooks;
+
 use futures::Stream;
 
 use std::time::Duration;
@@ -53,7 +60,7 @@ pub use self::{
 /// [module-level documentation]: mod@self
 pub trait UpdateListener<E>: for<'a> AsUpdateStream<'a, E> {
     /// The type of token which allows to stop this listener.
-    type StopToken: StopToken;
+    type StopToken: StopToken + Send;
 
     /// Returns a token which stops this listener.
     ///  
